==> haskell-th-lift-instances-0.1.11-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
key: th-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
license: BSD-3-Clause
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Benno Fünfstück
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
abi: 3e3fcceefc96bb41e808a3766a723a8c
exposed: True
exposed-modules:
    Instances.TH.Lift
import-dirs: /usr/lib/ghc-8.6.2/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.6.2/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-kskbiD4rBaLror4VPYRuF
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-lift-instances-0.1.11-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-th-lift-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-lift-instances
version: 0.1.11
id: th-lift-instances-0.1.11-HbkbhodRA4HR9WZPtc4Ly
key: th-lift-instances-0.1.11-HbkbhodRA4HR9WZPtc4Ly
license: BSD-3-Clause
copyright: Copyright (C) 2013-2016 Benno Fünfstück
maintainer: Benno Fünfstück <benno.fuenfstueck@gmail.com>
author: Benno Fünfstück
stability: experimental
homepage: http://github.com/bennofs/th-lift-instances/
synopsis: Lift instances for template-haskell for common data types.
description:
    Most data types in haskell platform do not have Lift instances. This package provides orphan instances
    for containers, text, bytestring and vector.
category: Template Haskell
abi: 4705eac75c18a734422cc188c29220f1
exposed: True
exposed-modules:
    Instances.TH.Lift
import-dirs: /usr/lib/ghc-8.6.3/site-local/th-lift-instances-0.1.11
library-dirs: /usr/lib/ghc-8.6.3/site-local/th-lift-instances-0.1.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/th-lift-instances-0.1.11
hs-libraries: HSth-lift-instances-0.1.11-HbkbhodRA4HR9WZPtc4Ly
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    template-haskell-2.14.0.0 text-1.2.3.1
    th-lift-0.7.11-JiIK3cdnl9dHd8tTTTgRnz
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-th-lift-instances/html/th-lift-instances.haddock
haddock-html: /usr/share/doc/haskell-th-lift-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
